@@ -1,8 +1,8 @@
 import typer
 from rich.console import Console
 from rich.table import Table
-from model import Todo
-from database import get_all_todos, delete_todo, insert_todo, complete_todo, update_todo, clear
+from .model import Todo
+from .database import get_all_todos, delete_todo, insert_todo, complete_todo, update_todo, clear
 from datetime import datetime
 
 console = Console()
@@ -80,11 +80,11 @@ def clear_screen(
     else:
         typer.echo("Operation canceled")
 
-
-def main():
-    print("calling main!!!")
-    app()
-
-
-if __name__ == "__main__":
-    main()
\ No newline at end of file
+#
+# def main():
+#     print("calling main!!!")
+#     app()
+#
+#
+# if __name__ == "__main__":
+#     main()
\ No newline at end of file
